angular.module('starter.controllers')
  .service('graphService', function($http, $q) {
    return {
      ////////////////
      startService: function(graphNames, username, timeformat, deviceinfo) {
        var deferred = $q.defer();
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = 1.2;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        var urlCalls = [];
        angular.forEach(graphNames, function(graphName) {
          var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/json-parse/' + graphName;
          urlCalls.push($http.get(url));
        });

        $q.all(urlCalls)
          .then(
            function(response) {
              var result = [];
              angular.forEach(response,function(resultResp){
                result.push(JSON.parse(resultResp.data.jsonStrArray))
              });
              deferred.resolve(
                result
              )
            },
            function(errors) {
              deferred.reject(errors);
            },
            function(updates) {
              deferred.update(updates);
            });
        return deferred.promise;
      }
    };
  })
  .factory('loginPromise', function($http, $q) {
    return {
      startService: function(username, password) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var urlAuth = "https://attdashboard.wireless.att.com/EDSGateway/auth";
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = password;
        $http.get(urlAuth, {
            async: true,
            cache: false,
          })
          .success(function(response) {
            def.resolve(response);
          }).error(function(response) {
            def.reject("login error");
          }).finally(function() {
            delete $http.defaults.headers.common['attEDSApplication'];
            delete $http.defaults.headers.common['attEDSUser'];
            delete $http.defaults.headers.common['attEDSUserPassword'];
          });
        return def.promise;
      }
    };
  })
  .factory('registrationPromise', function($http, $q) {
    return {
      startService: function(timeformat, deviceinfo, username, password, deviceType, deviceToken, getParams, version) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = "https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/user-notifications/registration";
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;

        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = password;
        $http.defaults.headers.common['Content-type'] = 'application/x-www-form-urlencoded';
        $http.post(url, getParams, 'application/x-www-form-urlencoded')
          .success(function(response) {
            def.resolve(response);
          }).error(function(response) {
            def.reject("registration error");
          }).finally(function() {
            delete $http.defaults.headers.common['attEDSApplication'];
            delete $http.defaults.headers.common['attEDSUser'];
            delete $http.defaults.headers.common['attEDSUserPassword'];
          });
        return def.promise;
      }
    };
  })
  .factory('aclPromise', function($http, $q) {
    return {
      startService: function(timeformat, deviceinfo, username, version) {
        var def = $q.defer();
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/user-profiles';
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        var data = {};
        $http.get(url, data, {
          cache: false
        }).success(function(response) {
          def.resolve(response);
        }).error(function(response) {
          def.reject(response);
        }).finally(function() {
          delete $http.defaults.headers.common['imoc-header-sent-time'];
          delete $http.defaults.headers.common['imoc-header-device-type'];
          delete $http.defaults.headers.common['imoc-header-application-version'];
          delete $http.defaults.headers.common['imoc-header-user-name'];
        });
        return def.promise;
      }
    };
  })
  .factory('teamDataPromise', function($http, $q) {
    return {
      startService: function(teamName, username, timeformat, deviceinfo, current, version) {
        var def = $q.defer();
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var teamnameAux = "";
        if (teamName == 'ongoing') {
          teamnameAux = 'amoc';
          teamName = teamnameAux;
        }
        // hard coded
        //teamName = 'attmx';
        //alert('teamName::'+teamName);
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v100/alerted-applications?team=' + teamName + '&appId=aPa';
        // if (!current) {
        //   url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v100/alerted-applications/history?team=' + teamName + '&appId=aPa';
        // }
        if (teamnameAux == "amoc") {
          teamName = 'ongoing';
        }
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        //alert(url);
        $http.get(url, {
            async: true,
            cache: false,
          })
          .success(function(response) {
            //alert(teamName+'::'+response.alertedApplications):
            def.resolve(response.alertedApplications);
          }).error(function(response) {
            def.reject("WS failure, Teamname: " + teamName);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
          });
        return def.promise;
      }
    };
  })
  .factory('countDataPromise', function($http, $q) {
    return {
      startService: function(username, timeformat, deviceinfo, version) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v100/alerted-applications/open-counts';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.get(url, {
            async: true,
            cache: false,
          })
          .success(function(response) {
            def.resolve(response.openAlertsCount);
          }).error(function(response) {
            def.reject("WS failure, alerts count: " + response);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }
    };
  })
  
  .factory('headsUpUpdateHistoryPromise', function($http, $q) {
    return {
      updateHistoryDtls: function(username, timeformat, deviceinfo, version,id) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/heads-up-details/updateHistory';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
       $http.post(url, "?&id="+id, 'application/x-www-form-urlencoded')
          .success(function(response) {
			//  console.log(response.lstJson);
            def.resolve(response.lstJson);
          }).error(function(response) {
            def.reject("WS failure while getting the image, error is : " + response);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }

    };
  })
  
 .factory('headsUpDetailsByIdPromise', function($http, $q) {
    return {
      getDetailsById: function(username, timeformat, deviceinfo, version,role,id) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/heads-up-details/getDetailsById';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.defaults.headers.common['Content-type'] = 'application/x-www-form-urlencoded';
        $http.post(url, "?&role=" + role + "&id=" + id, 'application/x-www-form-urlencoded')
    
           .success(function(response) {
			 // console.log(response.lstJson);
            def.resolve(response.lstJson);
          }).error(function(response) {
            def.reject("WS failure while getting the image, error is : " + response);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }

    };
  })

  .factory('headsUpOngoingPromise', function($http, $q) {
    return {
      ongoingDtls: function(username, timeformat, deviceinfo, version,role) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/heads-up-details/ongoing';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.defaults.headers.common['Content-type'] = 'application/x-www-form-urlencoded';
       $http.post(url, "?&role="+role, 'application/x-www-form-urlencoded')
          .success(function(response) {
			 // console.log(response.lstJson);
            def.resolve(response.lstJson);
          }).error(function(response) {
            def.reject("WS failure while getting the image, error is : " + response);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }

    };
  })

  .factory('headsUpClosedPromise', function($http, $q) {
    return {
      closedDtls: function(username, timeformat, deviceinfo, version,role) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/heads-up-details/closed';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.defaults.headers.common['Content-type'] = 'application/x-www-form-urlencoded';
       $http.post(url, "?&role="+role, 'application/x-www-form-urlencoded')
          .success(function(response) {
			  //console.log(response.lstJson);
            def.resolve(response.lstJson);
          }).error(function(response) {
            def.reject("WS failure while getting the image, error is : " + response);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }

    };
  })

  .factory('headsUpHistoryPromise', function($http, $q) {
    return {
      historyDtls: function(username, timeformat, deviceinfo, version,role) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/heads-up-details/history';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.defaults.headers.common['Content-type'] = 'application/x-www-form-urlencoded';
       $http.post(url, "?&role="+role, 'application/x-www-form-urlencoded')
          .success(function(response) {
			  //console.log(response.lstJson);
            def.resolve(response.lstJson);
          }).error(function(response) {
            def.reject("WS failure while getting the image, error is : " + response);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }

    };
  })


  .factory('headsUpCountPromise', function($http, $q) {
    return {
      startService: function(username, timeformat, deviceinfo, version,role) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/heads-up-count';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.defaults.headers.common['Content-type'] = 'application/x-www-form-urlencoded';
       $http.post(url, "?&role="+role, 'application/x-www-form-urlencoded')
          .success(function(response) {
            def.resolve(response.openCounts);
          }).error(function(response) {
            def.reject("WS failure while getting the image, error is : " + response);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }
    };
  })

  .factory('getImagePromise', function($http, $q) {
    return {
      startService: function(username, timeformat, deviceinfo, role, path, version) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/image-processing-json';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.post(url, "?&role=" + role + "&server-path=" + path, 'application/x-www-form-urlencoded')
          .success(function(response) {
            def.resolve(response);
          }).error(function(response) {
            def.reject("WS failurewhile getting the image, error is : " + response);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }
    };
  })
  .factory('graphsPromise', function($http, $q) {
    return {
      startService: function(graphName, username, timeformat, deviceinfo) {
        var def = $q.defer();
        ///*
        https: //attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/json-parse/FILENAME.json
          var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/json-parse/' + graphName;
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = 1.2;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        //*/
        //var url = 'https://s3.amazonaws.com/aws-website-amdocspsg-oz9ag/jsons/'+ graphName;
        $http.get(url, {
            async: true,
            cache: false,
          })
          .success(function(response) {
            def.resolve(JSON.parse(response.jsonStrArray));
          }).error(function(response) {
            def.reject("Unable to retrieve graph data: " + graphName);
          }).finally(function() {});
        return def.promise;
      }
    };
  })
  .factory('LoginService', function($http) {
    var isAuthenticated = false;
    return {
      setIsAuthenticated: function(amiLogged) {
        isAuthenticated = amiLogged;
      },
      isAuthenticated: function() {
        return isAuthenticated;
      },
      getCurrentParams: function() {
        return responseData;
      }
    };
  })
  .factory('QuickActionService', function($rootScope, $q) {
    return {
      configure: function(countP0, countP1) {
        window.ThreeDeeTouch.configureQuickActions([{
            type: 'p0',
            title: 'P0 Alerts',
            subtitle: 'Ongoing P0 Count : ' + countP0,
            iconType: 'taskCompleted'
          },
          {
            type: 'perf',
            title: 'Perf Alerts',
            subtitle: 'Ongoing P1 Count : ' + countP1,
            iconType: 'taskCompleted'
          },
          {
            type: 'home',
            title: 'Home',
            subtitle: 'Home Page',
            iconType: 'home'
          }
        ]);

        // Set event handler to check which Quick Action was pressed
        window.ThreeDeeTouch.onHomeIconPressed = function(payload) {
          if (payload.type == 'home') {
            $rootScope.$broadcast('homeScreenQuickAction');
          } else if (payload.type == 'iphoneStat') {
            $rootScope.$broadcast('iphoneStatQuickAction');
          } else if (payload.type == 'p0') {
            $rootScope.$broadcast('p0ScreenQuickAction');
          } else if (payload.type == 'perf') {
            $rootScope.$broadcast('perfScreenQuickAction');
          }
        };
      }
    };
  })
  .factory('getAppUpdateService', function($http, $q) {
    return {
      startService: function(username, timeformat, deviceinfo, version) {
        if (username.length != 6) {
          username = window.localStorage['username'];
        }
        var def = $q.defer();
        var phone = 'iPhone';
        if (deviceinfo == 'Android') {
          phone = 'android';
        }
        var url =
          //'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v100/application-client/update/' + phone;
          'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/application-client/update/' + phone + '?appId=ApStat';

        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.get(url, {
            async: true,
            cache: false,
          })
          .success(function(response) {
            def.resolve(response);
          }).error(function(response) {
            def.reject("WS failure while getting Application Updates");
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });
        return def.promise;
      }
    };
  })
  .factory('fetchDavDataService', function($http, $q) {
    return {

      startService: function(username, timeformat, deviceinfo, version, davUrl, getDavParams) {
        var def = $q.defer();
        if (username.length != 6) {
          username = window.localStorage['username'];
        }

        var phone = 'iPhone';
        if (deviceinfo == 'Android') {
          phone = 'android';
        }
        //Changes from Abbas
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/dav-mediator';

        var result = '';
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
        $http.defaults.headers.common['Content-Type'] = 'application/x-www-form-urlencoded';

        $http.post(url, getDavParams, 'application/x-www-form-urlencoded')
          .success(function(response) {
            def.resolve(response);
          }).error(function(response) {
            def.reject("WS failure while getting Data");
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
            delete $http.defaults.headers.common['Content-Type'];
          });

        return def.promise;

      }
    };
  })

  .factory('fetchWlmDataService', function($http, $q) {
    return {
      startService: function(username, timeformat, deviceinfo, version) {
        var def = $q.defer();
        if (username.length != 6) {
          username = window.localStorage['username'];
        }

        var phone = 'iPhone';
        if(deviceinfo == 'Android'){
          phone = 'android';
        }
        //Changes from Abbas
        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/wlm-mediator';

				var result ='';
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = version;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';
		$http.defaults.headers.common['Content-Type'] = 'application/x-www-form-urlencoded';

        $http.get(url, {
            async: true,
            cache: false,
          })
          .success(function(response) {
          		def.resolve(response);

          }).error(function(response) {
            def.reject("WS failure while getting Data");
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
 					  delete $http.defaults.headers.common['attEDSApplication'];
 					  delete $http.defaults.headers.common['Content-Type'];
          });

          return def.promise;

      }
    };
  })

  .factory('impactPromise', function($http, $q) {
    return {
      startService: function(lineName, username, timeformat, deviceinfo) {
        var def = $q.defer();

        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v200/impact-relation/' + lineName;
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = 1.2;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';

        $http.get(url, {
            async: true,
            cache: false,
          })
          .success(function(response) {
            def.resolve(response);
          }).error(function(response) {
            def.reject("Unable to retrieve Network data: " + lineName);
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });

        return def.promise;

      }
    };
  })
  .factory('impactMeterPromise', function($http, $q) {
    return {
      startService: function(username, timeformat, deviceinfo) {
        var def = $q.defer();

        var url = 'https://attdashboard.wireless.att.com/EDSGateway/forward/proc_rq/imoc_services/mobile_api/v300/alerted-applications/open-counts-per-line';
        $http.defaults.headers.common['imoc-header-sent-time'] = timeformat;
        $http.defaults.headers.common['imoc-header-device-type'] = deviceinfo;
        $http.defaults.headers.common['imoc-header-application-version'] = 1.2;
        $http.defaults.headers.common['imoc-header-user-name'] = username;
        $http.defaults.headers.common['attEDSUser'] = username;
        $http.defaults.headers.common['attEDSUserPassword'] = window.localStorage['password'];
        $http.defaults.headers.common['attEDSApplication'] = 'iMoc';

        $http.get(url, {
            async: true,
            cache: false,
          })
          .success(function(response) {
            def.resolve(response);
          }).error(function(response) {
            def.reject("Unable to retrieve data");
          }).finally(function() {
            delete $http.defaults.headers.common['imoc-header-sent-time'];
            delete $http.defaults.headers.common['imoc-header-device-type'];
            delete $http.defaults.headers.common['imoc-header-application-version'];
            delete $http.defaults.headers.common['imoc-header-user-name'];
            delete $http.defaults.headers.common['attEDSApplication'];
          });

        return def.promise;

      }
    };
  })
